#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Diff
version:              0.4.0
visibility:           public
id:                   Diff-0.4.0-13VXofqCMLyHuBACVASIzF
key:                  Diff-0.4.0-13VXofqCMLyHuBACVASIzF
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             O(ND) diff algorithm in haskell.
description:
    Implementation of the standard diff algorithm, and utilities for pretty printing.

category:             Algorithms
abi:                  54fe848fa01dee6270226fe2f6832833
exposed:              True
exposed-modules:
    Data.Algorithm.Diff Data.Algorithm.DiffContext
    Data.Algorithm.DiffOutput

import-dirs:          /usr/lib/ghc-8.10.5/site-local/Diff-0.4.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/Diff-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/Diff-0.4.0
hs-libraries:         HSDiff-0.4.0-13VXofqCMLyHuBACVASIzF
depends:              array-0.5.4.0 base-4.14.2.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-diff/html/Diff.haddock
haddock-html:         /usr/share/doc/haskell-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

